#include "Mouse.h"

// set pin numbers for switch, joystick axes, and LED:
const int switchPin = 2;    // switch to turn on and off mouse control
const int mouseButton = 3;  // input pin for the mouse pushButton

const int leftClickButton = 13; // pin de entrada para el botón de clic izquierdo
const int rightClickButton = 12; // pin de entrada para el botón de clic derecho

const int xAxis = A0;       // joystick X axis
const int yAxis = A1;       // joystick Y axis
const int ledPin = 5;       // Mouse control LED

// parameters for reading the joystick:
int range = 12;             // output range of X or Y movement
int responseDelay = 5;      // response delay of the mouse, in ms
int threshold = range / 4;  // resting threshold
int center = range / 2;     // resting position value

bool mouseIsActive = false;  // whether or not to control the mouse
int lastSwitchState = LOW;   // previous switch state
  // previous switch state
void setup() {
  pinMode(switchPin, INPUT);  // the switch pin
  pinMode(ledPin, OUTPUT);    // the LED pin

  pinMode(leftClickButton, INPUT_PULLUP); // pin de botón de clic izquierdo como entrada con pull-up
  pinMode(rightClickButton, INPUT_PULLUP); // pin de botón de clic derecho como entrada con pull-up

  // take control of the mouse:
  Mouse.begin();
}

void loop() {
  // read the switch:
  int switchState = digitalRead(switchPin);
  // if it's changed and it's high, toggle the mouse state:
  if (switchState != lastSwitchState) {
    if (switchState == HIGH) {
      mouseIsActive = !mouseIsActive;
      // turn on LED to indicate mouse state:
      digitalWrite(ledPin, mouseIsActive);
    }
  }
  // save switch state for next comparison:
  lastSwitchState = switchState;

  // read and scale the two axes:
  int xReading = readAxis(A0);
  int yReading = (-1)*readAxis(A1); //Lo multiplico por -1 para que la señal se invierta y no se mueva extraño el joystick

  // if the mouse control state is active, move the mouse:
  if (mouseIsActive) {
    Mouse.move(xReading, yReading, 0);

  // Verificación del botón de clic izquierdo
    if (digitalRead(leftClickButton) == LOW) { // Si el botón de clic izquierdo está presionado
      Mouse.press(MOUSE_LEFT); // Presionar el botón de clic izquierdo del mouse
    } else {
      Mouse.release(MOUSE_LEFT); // Soltar el botón de clic izquierdo del mouse
    }

    // Verificación del botón de clic derecho
    if (digitalRead(rightClickButton) == LOW) { // Si el botón de clic derecho está presionado
      Mouse.press(MOUSE_RIGHT); // Presionar el botón de clic derecho del mouse
    } else {
      Mouse.release(MOUSE_RIGHT); // Soltar el botón de clic derecho del mouse
    }
  }

  delay(responseDelay);
}

/*
  reads an axis (0 or 1 for x or y) and scales the analog input range to a range
  from 0 to <range>
*/

int readAxis(int thisAxis) {
  // read the analog input:
  int reading = analogRead(thisAxis);

  // map the reading from the analog input range to the output range:
  reading = map(reading, 0, 1023, 0, range);

  // if the output reading is outside from the rest position threshold, use it:
  int distance = reading - center;

  if (abs(distance) < threshold) {
    distance = 0;
  }

  // return the distance for this axis:
  return distance;
}
